/**
 * @class kDict
 * @brief Editable Dictionary object that holds keys and values
 */
class kDict
{
public:
	
	/**
	 * @brief Returns true if \a key exists
	 */
	const bool HasKey(const kStr &in key);
	
	/**
	 * @brief Adds a new key/value
	 */
	void Add(const kStr &in key, const kStr &in value);
	
	/**
	 * @brief Sets the value for the specified \a key
	 */
	void SetValue(const kStr &in key, const kStr &in value);
	
	/**
	 * @brief Removes all keys/values
	 */
	void Empty();
	
	/**
	 * @brief Returns true if found the key as a float type
	 */
	bool GetFloat(const kStr &in key, float &out floatResult, const float defaultValue = 0);
	
	/**
	 * @brief Returns true if found the key as a kVec3 type
	 */
	bool GetVector(const kStr &in key, kVec3 &out vectorResult);
	
	/**
	 * @brief Returns true if found the key as a string type
	 */
	bool GetString(const kStr &in key, kStr &out stringResult);
	
	/**
	 * @brief Returns true if found the key as a bool type
	 */
	bool GetBool(const kStr &in key, bool &out boolResult, const bool defaultValue = false);
	
	/**
	 * @brief Returns true if found the key as a int type
	 */
	bool GetInt(const kStr &in key, int &out intResult, const int defaultValue = 0);
};
